package com.zipcodewilmington.gildedrose;

import org.junit.Assert;
import org.junit.Test;

import java.util.ArrayList;

public class InventoryTest {

    @Test
    public void testAgedBrieIncreaseTo11() {
        Item agedBrie = new Item("Aged Brie", 10, 10);
        Item[] item = {agedBrie};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 11;
        int actual = agedBrie.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testAgedBrieIncreaseTo50() {
        Item agedBrie = new Item("Aged Brie", 10, 49);
        Item[] item = {agedBrie};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 50;
        int actual = agedBrie.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testAgedBrieOver50() {
        Item agedBrie = new Item("Aged Brie", 10, 50);
        Item[] item = {agedBrie};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 50;
        int actual = agedBrie.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstagePass10BeforeSellDay() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 11, 40);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 41;
        int actual = backstage.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstagePass7BeforeSellDay() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 7, 40);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 42;
        int actual = backstage.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstagePass3BeforeSellDay() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 3, 40);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 43;
        int actual = backstage.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstagePassOnSellDay() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 0, 40);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 43;
        int actual = backstage.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstagePassAfterSellDay() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", -1, 40);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 0;
        int actual = backstage.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testSulfuras() {
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 10, 40);
        Item[] item = {sulfuras};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 40;
        int actual = sulfuras.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testConjuredBeforeSellDay() {
        Item conjured = new Item("conjured", 5, 40);
        Item[] item = {conjured};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 38;
        int actual = conjured.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testConjuredAfterSellDay() {
        Item conjured = new Item("conjured", -1, 40);
        Item[] item = {conjured};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 36;
        int actual = conjured.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testConjuredQualityZero1() {
        Item conjured = new Item("conjured", 5, 0);
        Item[] item = {conjured};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 0;
        int actual = conjured.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testConjuredQualityZero2() {
        Item conjured = new Item("conjured", -1, 0);
        Item[] item = {conjured};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 0;
        int actual = conjured.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNormal1() {
        Item normal = new Item("normal", 5, 40);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 39;
        int actual = normal.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNormal2() {
        Item normal = new Item("normal", -1, 40);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 38;
        int actual = normal.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNormal3() {
        Item normal = new Item("normal", -1, 0);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 0;
        int actual = normal.getQuality();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNormal4() {
        Item normal = new Item("normal", 20, 0);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);
        inventory.updateQuality();
        int expected = 0;
        int actual = normal.getQuality();
        Assert.assertEquals(expected, actual);
    }

}

